==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/javascript/Bundle.java <==
package io.github.cdklabs.projen.javascript;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.831Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.Bundle")
@software.amazon.jsii.Jsii.Proxy(Bundle.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface Bundle extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The task that produces this bundle.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getBundleTask();

    /**
     * (experimental) Location of the output file (relative to project root).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getOutfile();

    /**
     * (experimental) The "watch" task for this bundle.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.Task getWatchTask() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Bundle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Bundle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<Bundle> {
        io.github.cdklabs.projen.Task bundleTask;
        java.lang.String outfile;
        io.github.cdklabs.projen.Task watchTask;

        /**
         * Sets the value of {@link Bundle#getBundleTask}
         * @param bundleTask The task that produces this bundle. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder bundleTask(io.github.cdklabs.projen.Task bundleTask) {
            this.bundleTask = bundleTask;
            return this;
        }

        /**
         * Sets the value of {@link Bundle#getOutfile}
         * @param outfile Location of the output file (relative to project root). This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder outfile(java.lang.String outfile) {
            this.outfile = outfile;
            return this;
        }

        /**
         * Sets the value of {@link Bundle#getWatchTask}
         * @param watchTask The "watch" task for this bundle.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder watchTask(io.github.cdklabs.projen.Task watchTask) {
            this.watchTask = watchTask;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Bundle}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public Bundle build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Bundle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Bundle {
        private final io.github.cdklabs.projen.Task bundleTask;
        private final java.lang.String outfile;
        private final io.github.cdklabs.projen.Task watchTask;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.bundleTask = software.amazon.jsii.Kernel.get(this, "bundleTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
            this.outfile = software.amazon.jsii.Kernel.get(this, "outfile", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.watchTask = software.amazon.jsii.Kernel.get(this, "watchTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.bundleTask = java.util.Objects.requireNonNull(builder.bundleTask, "bundleTask is required");
            this.outfile = java.util.Objects.requireNonNull(builder.outfile, "outfile is required");
            this.watchTask = builder.watchTask;
        }

        @Override
        public final io.github.cdklabs.projen.Task getBundleTask() {
            return this.bundleTask;
        }

        @Override
        public final java.lang.String getOutfile() {
            return this.outfile;
        }

        @Override
        public final io.github.cdklabs.projen.Task getWatchTask() {
            return this.watchTask;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("bundleTask", om.valueToTree(this.getBundleTask()));
            data.set("outfile", om.valueToTree(this.getOutfile()));
            if (this.getWatchTask() != null) {
                data.set("watchTask", om.valueToTree(this.getWatchTask()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.javascript.Bundle"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Bundle.Jsii$Proxy that = (Bundle.Jsii$Proxy) o;

            if (!bundleTask.equals(that.bundleTask)) return false;
            if (!outfile.equals(that.outfile)) return false;
            return this.watchTask != null ? this.watchTask.equals(that.watchTask) : that.watchTask == null;
        }

        @Override
        public final int hashCode() {
            int result = this.bundleTask.hashCode();
            result = 31 * result + (this.outfile.hashCode());
            result = 31 * result + (this.watchTask != null ? this.watchTask.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/javascript/Bundle.java <==
package io.github.cdklabs.projen.javascript;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.495Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.Bundle")
@software.amazon.jsii.Jsii.Proxy(Bundle.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface Bundle extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The task that produces this bundle.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getBundleTask();

    /**
     * (experimental) Base directory containing the output file (relative to project root).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getOutdir();

    /**
     * (experimental) Location of the output file (relative to project root).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getOutfile();

    /**
     * (experimental) The "watch" task for this bundle.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.Task getWatchTask() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Bundle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Bundle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<Bundle> {
        io.github.cdklabs.projen.Task bundleTask;
        java.lang.String outdir;
        java.lang.String outfile;
        io.github.cdklabs.projen.Task watchTask;

        /**
         * Sets the value of {@link Bundle#getBundleTask}
         * @param bundleTask The task that produces this bundle. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder bundleTask(io.github.cdklabs.projen.Task bundleTask) {
            this.bundleTask = bundleTask;
            return this;
        }

        /**
         * Sets the value of {@link Bundle#getOutdir}
         * @param outdir Base directory containing the output file (relative to project root). This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder outdir(java.lang.String outdir) {
            this.outdir = outdir;
            return this;
        }

        /**
         * Sets the value of {@link Bundle#getOutfile}
         * @param outfile Location of the output file (relative to project root). This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder outfile(java.lang.String outfile) {
            this.outfile = outfile;
            return this;
        }

        /**
         * Sets the value of {@link Bundle#getWatchTask}
         * @param watchTask The "watch" task for this bundle.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder watchTask(io.github.cdklabs.projen.Task watchTask) {
            this.watchTask = watchTask;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Bundle}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public Bundle build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Bundle}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Bundle {
        private final io.github.cdklabs.projen.Task bundleTask;
        private final java.lang.String outdir;
        private final java.lang.String outfile;
        private final io.github.cdklabs.projen.Task watchTask;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.bundleTask = software.amazon.jsii.Kernel.get(this, "bundleTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
            this.outdir = software.amazon.jsii.Kernel.get(this, "outdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.outfile = software.amazon.jsii.Kernel.get(this, "outfile", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.watchTask = software.amazon.jsii.Kernel.get(this, "watchTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.bundleTask = java.util.Objects.requireNonNull(builder.bundleTask, "bundleTask is required");
            this.outdir = java.util.Objects.requireNonNull(builder.outdir, "outdir is required");
            this.outfile = java.util.Objects.requireNonNull(builder.outfile, "outfile is required");
            this.watchTask = builder.watchTask;
        }

        @Override
        public final io.github.cdklabs.projen.Task getBundleTask() {
            return this.bundleTask;
        }

        @Override
        public final java.lang.String getOutdir() {
            return this.outdir;
        }

        @Override
        public final java.lang.String getOutfile() {
            return this.outfile;
        }

        @Override
        public final io.github.cdklabs.projen.Task getWatchTask() {
            return this.watchTask;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("bundleTask", om.valueToTree(this.getBundleTask()));
            data.set("outdir", om.valueToTree(this.getOutdir()));
            data.set("outfile", om.valueToTree(this.getOutfile()));
            if (this.getWatchTask() != null) {
                data.set("watchTask", om.valueToTree(this.getWatchTask()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.javascript.Bundle"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Bundle.Jsii$Proxy that = (Bundle.Jsii$Proxy) o;

            if (!bundleTask.equals(that.bundleTask)) return false;
            if (!outdir.equals(that.outdir)) return false;
            if (!outfile.equals(that.outfile)) return false;
            return this.watchTask != null ? this.watchTask.equals(that.watchTask) : that.watchTask == null;
        }

        @Override
        public final int hashCode() {
            int result = this.bundleTask.hashCode();
            result = 31 * result + (this.outdir.hashCode());
            result = 31 * result + (this.outfile.hashCode());
            result = 31 * result + (this.watchTask != null ? this.watchTask.hashCode() : 0);
            return result;
        }
    }
}
